@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast and Michael Zucchi
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast and Michael Zucchi
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -506,60 +506,45 @@ g_mime_encoding_base64_decode_step (const unsigned char *inbuf, size_t inlen, un
 	const unsigned char *inend;
 	register guint32 saved;
 	unsigned char c;
-	int npad, n, i;
+	int i;
 	
 	inend = inbuf + inlen;
 	outptr = outbuf;
-	inptr = inbuf;
-	
-	npad = (*state >> 8) & 0xff;
-	n = *state & 0xff;
-	saved = *save;
 	
 	/* convert 4 base64 bytes to 3 normal bytes */
+	saved = *save;
+	i = *state;
+	inptr = inbuf;
 	while (inptr < inend) {
 		c = gmime_base64_rank[*inptr++];
 		if (c != 0xff) {
 			saved = (saved << 6) | c;
-			n++;
-			if (n == 4) {
+			i++;
+			if (i == 4) {
 				*outptr++ = saved >> 16;
 				*outptr++ = saved >> 8;
 				*outptr++ = saved;
-				n = 0;
-				
-				if (npad > 0) {
-					outptr -= npad;
-					npad = 0;
-				}
+				i = 0;
 			}
 		}
 	}
 	
-	/* quickly scan back for '=' on the end somewhere */
-	/* fortunately we can drop 1 output char for each trailing '=' (up to 2) */
-	for (i = 2; inptr > inbuf && i; ) {
+	*save = saved;
+	*state = i;
+	
+	/* quick scan back for '=' on the end somewhere */
+	/* fortunately we can drop 1 output char for each trailing = (upto 2) */
+	i = 2;
+	while (inptr > inbuf && i) {
 		inptr--;
 		if (gmime_base64_rank[*inptr] != 0xff) {
-			if (*inptr == '=' && outptr > outbuf) {
-				if (n == 0) {
-					/* we've got a complete quartet so it's
-					   safe to drop an output character. */
-					outptr--;
-				} else if (npad < 2) {
-					/* keep a record of the number of ='s at
-					   the end of the input stream, up to 2 */
-					npad++;
-				}
-			}
-			
+			if (*inptr == '=' && outptr > outbuf)
+				outptr--;
 			i--;
 		}
 	}
 	
-	*state = (npad << 8) | n;
-	*save = n ? saved : 0;
-	
+	/* if i != 0 then there is a truncation error! */
 	return (outptr - outbuf);
 }
 
@@ -902,12 +887,7 @@ g_mime_encoding_quoted_encode_close (const unsigned char *inbuf, size_t inlen, u
 		}
 	}
 	
-	if (last != '\n') {
-		/* we end with =\n so that the \n isn't interpreted as a real
-		   \n when it gets decoded later */
-		*outptr++ = '=';
-		*outptr++ = '\n';
-	}
+	*outptr++ = '\n';
 	
 	*save = 0;
 	*state = -1;
